summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/kdiff3.cpp6
-rw-r--r--src/kdiff3_part.cpp2
-rw-r--r--src/kdiff3_shell.cpp6
-rw-r--r--src/kreplacements/kreplacements.cpp10
-rw-r--r--src/kreplacements/kreplacements.h4
5 files changed, 14 insertions, 14 deletions
diff --git a/src/kdiff3.cpp b/src/kdiff3.cpp
index 83eb692..acef944 100644
--- a/src/kdiff3.cpp
+++ b/src/kdiff3.cpp
@@ -130,7 +130,7 @@ KDiff3App::KDiff3App(TQWidget* pParent, const char* name, KDiff3Part* pKDiff3Par
m_pOptionDialog = new OptionDialog( m_pKDiff3Shell!=0, this );
connect( m_pOptionDialog, TQ_SIGNAL(applyClicked()), this, TQ_SLOT(slotRefresh()) );
- m_pOptionDialog->readOptions( isPart() ? m_pKDiff3Part->instance()->config() : kapp->config() );
+ m_pOptionDialog->readOptions( isPart() ? m_pKDiff3Part->instance()->config() : tdeApp->config() );
// Option handling: Only when pParent==0 (no parent)
TDECmdLineArgs *args = isPart() ? 0 : TDECmdLineArgs::parsedArgs();
@@ -277,7 +277,7 @@ KDiff3App::KDiff3App(TQWidget* pParent, const char* name, KDiff3Part* pKDiff3Par
m_pDirectoryMergeSplitter = new TQSplitter( m_pMainSplitter );
m_pDirectoryMergeSplitter->setOrientation(TQt::Horizontal );
m_pDirectoryMergeWindow = new DirectoryMergeWindow( m_pDirectoryMergeSplitter, m_pOptionDialog,
- TDEApplication::kApplication()->iconLoader() );
+ tdeApp->iconLoader() );
m_pDirectoryMergeInfo = new DirectoryMergeInfo( m_pDirectoryMergeSplitter );
m_pDirectoryMergeWindow->setDirectoryMergeInfo( m_pDirectoryMergeInfo );
connect( m_pDirectoryMergeWindow, TQ_SIGNAL(startDiffMerge(TQString,TQString,TQString,TQString,TQString,TQString,TQString,TotalDiffStatus*)),
@@ -593,7 +593,7 @@ void KDiff3App::saveOptions( TDEConfig* config )
bool KDiff3App::queryClose()
{
- saveOptions( isPart() ? m_pKDiff3Part->instance()->config() : kapp->config() );
+ saveOptions( isPart() ? m_pKDiff3Part->instance()->config() : tdeApp->config() );
if(m_bOutputModified)
{
diff --git a/src/kdiff3_part.cpp b/src/kdiff3_part.cpp
index aa0760c..75fa4ad 100644
--- a/src/kdiff3_part.cpp
+++ b/src/kdiff3_part.cpp
@@ -69,7 +69,7 @@ KDiff3Part::~KDiff3Part()
{
if ( m_widget!=0 && ! m_bIsShell )
{
- m_widget->saveOptions( m_widget->isPart() ? instance()->config() : kapp->config() );
+ m_widget->saveOptions( m_widget->isPart() ? instance()->config() : tdeApp->config() );
}
}
diff --git a/src/kreplacements/kreplacements.cpp b/src/kreplacements/kreplacements.cpp
index e6d9065..a742ca1 100644
--- a/src/kreplacements/kreplacements.cpp
+++ b/src/kreplacements/kreplacements.cpp
@@ -978,12 +978,12 @@ bool TDECmdLineArgs::isSet(const TQString& s)
}
///////////////////
-TDEApplication* kapp;
+TDEApplication* tdeApp;
TDEApplication::TDEApplication()
: TQApplication( s_argc,s_argv )
{
- kapp = this;
+ tdeApp = this;
int nofOptions=0;
int nofArgs=0;
@@ -1119,9 +1119,9 @@ bool TDEApplication::isRestored()
return false;
}
-TDEApplication* TDEApplication::kApplication()
+TDEApplication* TDEApplication::tdeApplication()
{
- return kapp;
+ return tdeApp;
}
TDEIconLoader* TDEApplication::iconLoader()
@@ -1152,7 +1152,7 @@ TDEActionCollection* KParts::Part::actionCollection()
TDEApplication* KParts::Part::instance()
{
- return kapp;
+ return tdeApp;
}
diff --git a/src/kreplacements/kreplacements.h b/src/kreplacements/kreplacements.h
index cc8c2ab..f822319 100644
--- a/src/kreplacements/kreplacements.h
+++ b/src/kreplacements/kreplacements.h
@@ -381,13 +381,13 @@ class TDEApplication : public TQApplication
TDEIconLoader m_iconLoader;
public:
TDEApplication();
- static TDEApplication* kApplication();
+ static TDEApplication* tdeApplication();
TDEIconLoader* iconLoader();
TDEConfig* config();
bool isRestored();
};
-extern TDEApplication* kapp;
+extern TDEApplication* tdeApp;
class KLibFactory : public TQObject
{
diff --git a/src/kdiff3_shell.cpp b/src/kdiff3_shell.cpp
index f740c3b..10c440a 100644
--- a/src/kdiff3_shell.cpp
+++ b/src/kdiff3_shell.cpp
@@ -79,11 +79,11 @@ KDiff3Shell::KDiff3Shell(bool bCompleteInit)
"This usually happens due to an installation problem. "
"Please read the README-file in the source package for details.")
);
- //kapp->quit();
+ //tdeApp->quit();
- ::exit(-1); //kapp->quit() doesn't work here yet.
+ ::exit(-1); //tdeApp->quit() doesn't work here yet.
- // we return here, cause kapp->quit() only means "exit the
+ // we return here, cause tdeApp->quit() only means "exit the
// next time we enter the event loop...
return;